Name:           spring-ldap
Version:        1.3.1
Release:        15%{?dist}
Summary:        Java library for simplifying LDAP operations
License:        ASL 2.0
URL:            http://www.springframework.org/ldap
# https://github.com/spring-projects/spring-ldap
# svn export https://src.springframework.org/svn/spring-ldap/tags/spring-ldap-1.3.1.RELEASE spring-ldap-1.3.1
# tar cfJ spring-ldap-1.3.1.tar.xz spring-ldap-1.3.1
Source0:        %{name}-%{version}.tar.xz
# Don't use ldapbp.jar, as I couldn't find the source and I doubt it has a valid
# open source license:
Patch0:         %{name}-remove-ldapbp.patch
# Use Java 5 to build the core as the JavaCC generated source code uses Java 5
# features like generics and annotations:
Patch1:         %{name}-use-java-5-to-build-core.patch
# Remove the dependency on spring-orm:
Patch2:         %{name}-remove-spring-orm.patch

BuildArch:      noarch

BuildRequires:  dos2unix
BuildRequires:  maven-local
BuildRequires:  mvn(commons-cli:commons-cli)
BuildRequires:  mvn(commons-codec:commons-codec)
BuildRequires:  mvn(commons-lang:commons-lang)
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(commons-pool:commons-pool)
BuildRequires:  mvn(gsbase:gsbase)
BuildRequires:  mvn(jdepend:jdepend)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(log4j:log4j)
BuildRequires:  mvn(org.apache.maven.plugins:maven-assembly-plugin)
BuildRequires:  mvn(org.codehaus.mojo:javacc-maven-plugin)
BuildRequires:  mvn(org.easymock:easymock)
BuildRequires:  mvn(org.freemarker:freemarker)
BuildRequires:  mvn(org.springframework:spring-beans)
BuildRequires:  mvn(org.springframework:spring-context)
BuildRequires:  mvn(org.springframework:spring-core)
BuildRequires:  mvn(org.springframework:spring-jdbc)
BuildRequires:  mvn(org.springframework:spring-tx)
BuildRequires:  mvn(org.springframework.batch:spring-batch-core)
BuildRequires:  mvn(org.springframework.batch:spring-batch-infrastructure)
BuildRequires:  mvn(org.springframework.batch:spring-batch-test)

%description
Spring LDAP is a Java library for simplifying LDAP operations, based on the
pattern of Spring's JdbcTemplate. The framework relieves the user of common
chores, such as looking up and closing contexts, looping through results,
encoding/decoding values and filters, and more. The LdapTemplate class
encapsulates all the plumbing work involved in traditional LDAP programming,
such as creating a DirContext, looping through NamingEnumerations, handling
exceptions and cleaning up resources. This leaves the programmer to handle the
important stuff - where to find data (DNs and Filters) and what do do with it
(map to and from domain objects, bind, modify, unbind, etc.), in the same way
that JdbcTemplate relieves the programmer of all but the actual SQL and how the
data maps to the domain model. In addition to this, Spring LDAP provides
transaction support, a pooling library, exception translation from
NamingExceptions to a mirrored unchecked Exception hierarchy, as well as
several utilities for working with filters, LDAP paths and Attributes.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep

# Unpack and patch the source:
%setup -q
# Build the core only
%pom_disable_module test-support
%pom_disable_module test

%pom_xpath_inject "pom:project/pom:parent" "<relativePath>../../parent/tiger</relativePath>" ldif/ldif-batch

%pom_remove_plugin :cobertura-maven-plugin parent

# Disable the AWS extension
%pom_xpath_remove "pom:build/pom:extensions" parent
%patch0 -p1
%patch1 -p1
%patch2 -p1

# Remove binary files:
find . -name '*.jar' -print -delete

# Fix line endings in documentation files:
dos2unix notice.txt
dos2unix license.txt
dos2unix readme.txt

%build

# Skip the tests for now, as they bring dependencies that are not available in
# the distribution right now:
%mvn_build -f -- -Dproject.build.sourceEncoding=UTF-8

%install
%mvn_install

%files -f .mfiles
%license license.txt notice.txt
%doc readme.txt

%files javadoc -f .mfiles-javadoc
%license license.txt notice.txt

%changelog
* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.1-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.1-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Sep 23 2015 gil cattaneo <puntogil@libero.it> 1.3.1-13
- fix BuildRequires list, removed self-reference

* Fri Jun 19 2015 Michal Srb <msrb@redhat.com> - 1.3.1-12
- Fix FTBFS

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Feb 11 2015 gil cattaneo <puntogil@libero.it> 1.3.1-10
- introduce license macro

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Oct 09 2013 gil cattaneo <puntogil@libero.it> 1.3.1-8
- enable ldif and odm modules

* Mon Aug 05 2013 gil cattaneo <puntogil@libero.it> 1.3.1-7
- rebuilt FTBFS in rawhide
- swith to Xmvn
- adapt to new guideline

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Feb 06 2013 Java SIG <java-devel@lists.fedoraproject.org> - 1.3.1-4
- Update for https://fedoraproject.org/wiki/Fedora_19_Maven_Rebuild
- Replace maven BuildRequires with maven-local

* Tue Jul 24 2012 Juan Hernandez <juan.hernandez@redhat.com> - 1.3.1-3
- Added maven-plugin-cobertura build time dependency

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Mar 23 2012 Juan Hernandez <juan.hernandez@redhat.com> 1.3.1-1
- Updated to upstream version 1.3.1

* Sat Feb 11 2012 Juan Hernandez <juan.hernandez@redhat.com> 1.3.0-1
- Initial packaging
